@@ -23,6 +23,7 @@
 #include <libintl.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <string.h>
 #include <time.h>
 #include <ldap.h>
 #include <libxml/parser.h>
@@ -155,7 +156,7 @@ resolve_address (const char  *address,
     {
       g_set_error (err, GCONF_ERROR,
 		   GCONF_ERROR_BAD_ADDRESS,
-		   _("Failed to get configurion file path from '%s'"),
+		   _("Failed to get configuration file path from '%s'"),
 		   address);
       return NULL;
     }
@@ -315,9 +316,9 @@ subst_variables (const char  *src,
 
           if (varend != NULL)
             {
-              char       *varname;
-              const char *varval;
-              guint       varval_len;
+              char *varname;
+              char *varval;
+              guint varval_len;
 
               performed_subst = TRUE;
 
@@ -335,6 +336,7 @@ subst_variables (const char  *src,
                 }
               
               strcpy (&retval[pos], varval);
+              g_free(varval);
               pos += varval_len;
 
               iter = varend + 1;
@@ -441,7 +443,7 @@ parse_conf_file (EvoSource  *esource,
     {
       g_set_error (err, GCONF_ERROR,
 		   GCONF_ERROR_PARSE_ERROR,
-		   _("Unable to parse xml file '%s'"),
+		   _("Unable to parse XML file '%s'"),
 		   esource->conf_file);
       return FALSE;
     }
