@@ -92,7 +92,7 @@ gconf_key_check(const gchar* key, GError** err)
     {
       if (err)
         *err = gconf_error_new (GCONF_ERROR_BAD_KEY,
-				_("Key \"%s\" is NULL"), "(null)");
+				_("Key is NULL"));
       return FALSE;
     }
   else if (!gconf_valid_key (key, &why))
@@ -710,7 +710,7 @@ gconf_engine_unref(GConfEngine* conf)
                       /* Don't set error because realistically this
                          doesn't matter to clients */
 #ifdef GCONF_ENABLE_DEBUG
-                      g_warning("Failure removing listener %u from the config server: %s",
+                      g_warning("Failure removing listener %u from the configuration server: %s",
                                 (guint)gcnxn->server_id,
                                 err->message);
 #endif
@@ -2321,7 +2321,7 @@ gconf_detach_config_server(void)
  * gconf_debug_shutdown:
  * @void: 
  * 
- * Detach from the config server and release
+ * Detach from the configuration server and release
  * all related resources.
  *
  * Returns: 1 if an exception occurs, 0 otherwise.
@@ -2620,7 +2620,7 @@ gconf_valid_key      (const gchar* key, gchar** why_invalid)
   if (*key != '/')
     {
       if (why_invalid != NULL)
-        *why_invalid = g_strdup(_("Must begin with a slash (/)"));
+        *why_invalid = g_strdup(_("Must begin with a slash '/'"));
       return FALSE;
     }
   
@@ -2642,9 +2642,9 @@ gconf_valid_key      (const gchar* key, gchar** why_invalid)
               if (why_invalid != NULL)
                 {
                   if (*s == '/')
-                    *why_invalid = g_strdup(_("Can't have two slashes (/) in a row"));
+                    *why_invalid = g_strdup(_("Can't have two slashes '/' in a row"));
                   else
-                    *why_invalid = g_strdup(_("Can't have a period (.) right after a slash (/)"));
+                    *why_invalid = g_strdup(_("Can't have a period '.' right after a slash '/'"));
                 }
               return FALSE;
             }
@@ -2664,10 +2664,8 @@ gconf_valid_key      (const gchar* key, gchar** why_invalid)
           if (c > 127)
             {
               if (why_invalid != NULL)
-/*                *why_invalid = g_strdup_printf (_("'\\%o' is not an ASCII character, so isn't allowed in key names"),
-                                                (guint) c);*/
-                *why_invalid = g_strdup_printf (_("'%c' is not an ASCII character, so isn't allowed in key names"), (char) '?');
-
+                *why_invalid = g_strdup_printf (_("'\\%o' is not an ASCII character and thus isn't allowed in key names"),
+                                                (guint) c);
               return FALSE;
             }
           
@@ -2690,7 +2688,7 @@ gconf_valid_key      (const gchar* key, gchar** why_invalid)
   if (just_saw_slash)
     {
       if (why_invalid != NULL)
-        *why_invalid = g_strdup(_("Key/directory may not end with a slash (/)"));
+        *why_invalid = g_strdup(_("Key/directory may not end with a slash '/'"));
       return FALSE;
     }
   else
@@ -3061,7 +3059,7 @@ gconf_shutdown_daemon (GError** err)
   if (ev._major != CORBA_NO_EXCEPTION)
     {
       if (err)
-        *err = gconf_error_new (GCONF_ERROR_FAILED, _("Failure shutting down config server: %s"),
+        *err = gconf_error_new (GCONF_ERROR_FAILED, _("Failure shutting down configuration server: %s"),
                                 CORBA_exception_id (&ev));
 
       CORBA_exception_free(&ev);
